==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ca\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Línia"

, "Caller Id"
: "Identificador de qui truca"

, "Start"
: "Inici"

, "Connected"
: "Connectat"

, "Disconnected"
: "Desconnectat"

, "Duration"
: "Durada"

, "Ringing"
: "Sonant"

, "Direction"
: "Direcció"

, "Source"
: "Font"

, "Destination"
: "Destinació"

, "Phone"
: ""

, "Phones"
: "Telèfons"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Número"

, "Cancel"
: "Cancel·la"

, "Dial"
: "To"

, "Error"
: "Error"

, "Not possible to dial."
: "No ha estat possible agafar to."

, "Edit phone settings"
: "Edita la configuració de telèfon"

, "Dial number"
: "Número a marcar"

, "Initiate a new outgoing call"
: "Inicia una nova trucada"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Incoming call"
: "Trucada entrant"

, "Outgoing call"
: "Trucada sortint"

, "unknown number"
: "número desconegut"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Trucada entrant"

, "Outgoing call"
: "Trucada sortint"

, "unknown number"
: "número desconegut"

, "Phone"
: ""

, "Line"
: "Línia"

, "Number"
: "Número"

, "Cancel"
: "Cancel·la"

, "Dial"
: "To"

, "Error"
: "Error"

, "Not possible to dial."
: "No ha estat possible agafar to."

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Edit phone settings"
: "Edita la configuració de telèfon"

, "Dial number"
: "Número a marcar"

, "Initiate a new outgoing call"
: "Inicia una nova trucada"

, "Phones"
: "Telèfons"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Identificador de qui truca"

, "Start"
: "Inici"

, "Connected"
: "Connectat"

, "Disconnected"
: "Desconnectat"

, "Duration"
: "Durada"

, "Ringing"
: "Sonant"

, "Direction"
: "Direcció"

, "Source"
: "Font"

, "Destination"
: "Destinació"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
